<?php

/*===============================================*\
|| ############################################# ||
|| # JAKWEB.CH / Version 3.1                   # ||
|| # ----------------------------------------- # ||
|| # Copyright 2018 JAKWEB All Rights Reserved # ||
|| ############################################# ||
\*===============================================*/

// Error reporting:
error_reporting(E_ALL^E_NOTICE);

// The DB connections data
require_once 'include/db.php';

// Do not go any further if install folder still exists
if (is_dir('install')) die('Please delete or rename install folder.');

if (!JAK_CACHE_DIRECTORY) die('Please define a cache directory in the db.php.');

// Don't call some update twice
if (!isset($_SESSION['jkwio'])) $_SESSION['jkwio'] = false;

// Start the session
session_start();

// Absolute Path
define('APP_PATH', dirname(__file__) . DIRECTORY_SEPARATOR);

if (isset($_SERVER['SCRIPT_NAME'])) {

    # on Windows _APP_MAIN_DIR becomes \ and abs url would look something like HTTP_HOST\/restOfUrl, so \ should be trimed too
    # @modified Chis Florinel <chis.florinel@candoo.ro>
    $app_main_dir = rtrim(dirname($_SERVER['SCRIPT_NAME']), '/\\');
    define('_APP_MAIN_DIR', $app_main_dir);
} else {
    die('[config.php] Cannot determine APP_MAIN_DIR, please set manual and comment this line');
}

// Get the DB class
require_once 'class/class.db.php';

// Change for 3.0.3
use JAKWEB\JAKsql;

// Database connection
$jakdb = new JAKsql([
    // required
    'database_type' => JAKDB_DBTYPE,
    'database_name' => JAKDB_NAME,
    'server' => JAKDB_HOST,
    'username' => JAKDB_USER,
    'password' => JAKDB_PASS,
    'charset' => 'utf8',
    'port' => JAKDB_PORT,
    'prefix' => JAKDB_PREFIX,
 
    // [optional] driver_option for connection, read more from http://www.php.net/manual/en/pdo.setattribute.php
    'option' => [PDO::ATTR_CASE => PDO::CASE_NATURAL]
    ]);

// All important files
include_once 'include/functions.php';
include_once 'class/class.browser.php';
include_once 'class/class.jakbase.php';
include_once 'class/PHPMailerAutoload.php';
include_once 'class/class.userlogin.php';
include_once 'class/class.user.php';
include_once 'class/class.clientlogin.php';
include_once 'class/class.client.php';

// Windows Fix if !isset REQUEST_URI
if (!isset($_SERVER['REQUEST_URI']))
{
	$_SERVER['REQUEST_URI'] = substr($_SERVER['PHP_SELF'],1 );
	if (isset($_SERVER['QUERY_STRING'])) { $_SERVER['REQUEST_URI'].='?'.$_SERVER['QUERY_STRING']; }
}

// Now launch the rewrite class, depending on the settings in db.
$_SERVER['REQUEST_URI'] = htmlspecialchars($_SERVER['REQUEST_URI'], ENT_QUOTES);
$getURL = New JAK_rewrite($_SERVER['REQUEST_URI']);

// We are not using apache so take the ugly urls
$tempp = $getURL->jakGetseg(0);
$tempp1 = $getURL->jakGetseg(1);
$tempp2 = $getURL->jakGetseg(2);
$tempp3 = $getURL->jakGetseg(3);
$tempp4 = $getURL->jakGetseg(4);
$tempp5 = $getURL->jakGetseg(5);
$tempp6 = $getURL->jakGetseg(6);
$tempp7 = $getURL->jakGetseg(7);

// Check if we want caching
if (!is_dir(APP_PATH.JAK_CACHE_DIRECTORY)) mkdir(APP_PATH.JAK_CACHE_DIRECTORY, 0755);

// define file better for caching
$cachedefinefile = APP_PATH.JAK_CACHE_DIRECTORY.'/define.php';

if (!file_exists($cachedefinefile)) {

$allsettings = "<?php\n";

// Get the general settings out the database
$datasett = $jakdb->select("settings",["varname", "used_value"]);
foreach ($datasett as $row) {
    // Now check if sting contains html and do something about it!
    if (strlen($row['used_value']) != strlen(filter_var($row['used_value'], FILTER_SANITIZE_STRING))) {
    	$defvar  = 'htmlspecialchars_decode("'.htmlspecialchars($row['used_value']).'")';
    } else {
    	$defvar = "'".$row["used_value"]."'";
    }
    	
    $allsettings .= "define('JAK_".strtoupper($row['varname'])."', ".$defvar.");\n";
}
    
$allsettings .= "?>";
        
JAK_base::jakWriteinCache($cachedefinefile, $allsettings, '');

}

// Now include the created definefile
include_once $cachedefinefile;

// define file better for caching
$cachestufffile = APP_PATH.JAK_CACHE_DIRECTORY.'/stuff.php';

if (!file_exists($cachestufffile)) {

// empty vars
$filesgrid = $answergrid = $responsegrid = $responsetgrid = $departmentgrid = $departmentsgrid = $faqgrid = $autoproactivegrid = array();

$allstuff = "<?php\n";

// Get the general settings out the database
$datafiles = $jakdb->select("files",["id", "path", "name"]);
if (isset($datafiles) && !empty($datafiles)) foreach ($datafiles as $rowf) {
    $filesgrid[] = $rowf;
}
    
// Get the answers out the database
$dataansw = $jakdb->select("answers", ["id", "department", "lang", "message", "fireup", "msgtype"]);
if (isset($dataansw) && !empty($dataansw)) foreach ($dataansw as $rowa) {
    $answergrid[] = $rowa;
}

// Get the url black list
$databl = $jakdb->select("urlblacklist", "path");
if (isset($databl) && !empty($databl)) foreach ($databl as $rowb) {
    $blacklistgrid[] = $rowb;
}
    
// Get the responses settings out the database
$datares = $jakdb->select("responses", ["id", "department", "title", "message"]);
if (isset($datares) && !empty($datares)) foreach ($datares as $rowr) {
    $responsegrid[] = $rowr;
}

// Get the responses settings out the database
$datarest = $jakdb->select("support_responses", ["id", "depid", "title", "message"]);
if (isset($datarest) && !empty($datarest)) foreach ($datarest as $rowrt) {
    $responsetgrid[] = $rowrt;
}

// Get the chat bot out of the database
$databot = $jakdb->select("bot_question", ["id", "widgetids", "depid", "lang", "question", "answer"], ["active" => 1]);
if (isset($databot) && !empty($databot)) foreach ($databot as $rowba) {
    $botgrid[] = $rowba;
}
    
// Get the departments
$datadep = $jakdb->select("departments", ["id", "title", "email", "faq_url", "credits", "guesta"], ["active" => 1, "ORDER" => ["dorder" => "ASC"]]);
if (isset($datadep) && !empty($datadep)) foreach ($datadep as $rowd) {
    $departmentgrid[] = $rowd;
}

// Get the support departments
$datadeps = $jakdb->select("support_departments", ["id", "title", "email", "faq_url", "credits", "guesta"], ["active" => 1, "ORDER" => ["dorder" => "ASC"]]);
if (isset($datadeps) && !empty($datadeps)) foreach ($datadeps as $rowds) {
    $departmentsgrid[] = $rowds;
}

// Get the faq categories
$datafaq = $jakdb->select("faq_categories", ["id", "title", "email", "guesta"], ["active" => 1, "ORDER" => ["dorder" => "ASC"]]);
if (isset($datafaq) && !empty($datafaq)) foreach ($datafaq as $rowfaq) {
    $faqgrid[] = $rowfaq;
}
    
// Get the auto proactive out the database
$dataproact = $jakdb->select("autoproactive", ["path", "title", "imgpath", "message", "btn_confirm", "btn_cancel", "showalert", "soundalert", "timeonsite", "visitedsites"]);
if (isset($dataproact) && !empty($dataproact)) foreach ($dataproact as $rowap) {
    $autoproactivegrid[] = $rowap;
}
    
if (!empty($answergrid)) $allstuff .= "\$answergserialize = '".base64_encode(gzcompress(serialize($answergrid)))."';\n\n\$HD_ANSWERS = unserialize(gzuncompress(base64_decode(\$answergserialize)));\n\n";

if (!empty($blacklistgrid)) $allstuff .= "\$blacklistserialize = '".base64_encode(gzcompress(serialize($blacklistgrid)))."';\n\n\$HD_BLACKLIST = unserialize(gzuncompress(base64_decode(\$blacklistserialize)));\n\n";
    
if (!empty($responsegrid)) $allstuff .= "\$responsegserialize = '".base64_encode(gzcompress(serialize($responsegrid)))."';\n\n\$HD_RESPONSES = unserialize(gzuncompress(base64_decode(\$responsegserialize)));\n\n";

if (!empty($responsetgrid)) $allstuff .= "\$responsetgserialize = '".base64_encode(gzcompress(serialize($responsetgrid)))."';\n\n\$HD_RESPONSEST = unserialize(gzuncompress(base64_decode(\$responsetgserialize)));\n\n";

if (!empty($botgrid)) $allstuff .= "\$botserialize = '".base64_encode(gzcompress(serialize($botgrid)))."';\n\n\$JAK_BOT_ANSWER = unserialize(gzuncompress(base64_decode(\$botserialize)));\n\n";
    
if (!empty($filesgrid)) $allstuff .= "\$filesgserialize = '".base64_encode(gzcompress(serialize($filesgrid)))."';\n\n\$HD_FILES = unserialize(gzuncompress(base64_decode(\$filesgserialize)));\n\n";

$allstuff .= "\$departmentgserialize = '".base64_encode(gzcompress(serialize($departmentgrid)))."';\n\n\$HD_DEPARTMENTS = unserialize(gzuncompress(base64_decode(\$departmentgserialize)));\n\n";

$allstuff .= "\$departmentsgserialize = '".base64_encode(gzcompress(serialize($departmentsgrid)))."';\n\n\$HD_SUPPORT_DEPARTMENTS = unserialize(gzuncompress(base64_decode(\$departmentsgserialize)));\n\n";

$allstuff .= "\$faqgserialize = '".base64_encode(gzcompress(serialize($faqgrid)))."';\n\n\$HD_FAQ_CATEGORIES = unserialize(gzuncompress(base64_decode(\$faqgserialize)));\n\n";

if (!empty($autoproactivegrid)) $allstuff .= "\$autoproactiveserialize = '".base64_encode(gzcompress(serialize($autoproactivegrid)))."';\n\n\$HD_PROACTIVE = unserialize(gzuncompress(base64_decode(\$autoproactiveserialize)));\n\n";
    
$allstuff .= "?>";
        
JAK_base::jakWriteinCache($cachestufffile, $allstuff, '');

}

// Now include the created definefile
include_once $cachestufffile;

// Chat widget caching
$cachewidget = APP_PATH.JAK_CACHE_DIRECTORY.'/widget1.php';

if (!file_exists($cachewidget)) {

    // Get the general settings out the database
    $reswidg = $jakdb->select("chatwidget", "*");
    if (isset($reswidg) && !empty($reswidg)) {

        foreach ($reswidg as $row) {

            // Now let us delete the widget cache file
            $cachewidgetdel = APP_PATH.JAK_CACHE_DIRECTORY.'/widget'.$row['id'].'.php';
            if (file_exists($cachewidgetdel)) {
                unlink($cachewidgetdel);
            }

            $allwidget = "<?php\n\$jakwidget = array();\n";

            $allwidget .= "\$jakwidget['id'] = '".$row['id']."';\n\$jakwidget['title'] = '".stripcslashes($row['title'])."';\n\$jakwidget['depid'] = ".$row['depid'].";\n\$jakwidget['opid'] = ".$row['opid'].";\n\$jakwidget['lang'] = '".stripcslashes($row['lang'])."';\n\$jakwidget['widget'] = ".$row['widget'].";\n\$jakwidget['hideoff'] = ".$row['hideoff'].";\n\$jakwidget['buttonimg'] = '".stripcslashes($row['buttonimg'])."';\n\$jakwidget['mobilebuttonimg'] = '".stripcslashes($row['mobilebuttonimg'])."';\n\$jakwidget['slideimg'] = '".stripcslashes($row['slideimg'])."';\n\$jakwidget['floatpopup'] = ".$row['floatpopup'].";\n\$jakwidget['chat_direct'] = ".$row['chat_direct'].";\n\$jakwidget['client_email'] = ".$row['client_email'].";\n\$jakwidget['client_semail'] = ".$row['client_semail'].";\n\$jakwidget['client_phone'] = ".$row['client_phone'].";\n\$jakwidget['client_sphone'] = ".$row['client_sphone'].";\n\$jakwidget['client_question'] = ".$row['client_question'].";\n\$jakwidget['client_squestion'] = ".$row['client_squestion'].";\n\$jakwidget['show_avatar'] = ".$row['show_avatar'].";\n\$jakwidget['floatcss'] = '".stripcslashes($row['floatcss'])."';\n\$jakwidget['floatcsschat'] = '".stripcslashes($row['floatcsschat'])."';\n\$jakwidget['btn_animation'] = '".stripcslashes($row['btn_animation'])."';\n\$jakwidget['chat_animation'] = '".stripcslashes($row['chat_animation'])."';\n\$jakwidget['sucolor'] = '".stripcslashes($row['sucolor'])."';\n\$jakwidget['sutcolor'] = '".stripcslashes($row['sutcolor'])."';\n\$jakwidget['template'] = '".stripcslashes($row['template'])."';\n\$jakwidget['theme_colour'] = '".stripcslashes($row['theme_colour'])."';\n\$jakwidget['body_colour'] = '".$row['body_colour']."';\n\$jakwidget['h_colour'] = '".$row['h_colour']."';\n\$jakwidget['c_colour'] = '".$row['c_colour']."';\n\$jakwidget['time_colour'] = '".$row['time_colour']."';\n\$jakwidget['link_colour'] = '".$row['link_colour']."';\n\$jakwidget['sidebar_colour'] = '".$row['sidebar_colour']."';\n\$jakwidget['t_font'] = '".stripcslashes($row['t_font'])."';\n\$jakwidget['h_font'] = '".stripcslashes($row['h_font'])."';\n\$jakwidget['c_font'] = '".stripcslashes($row['c_font'])."';\n\$jakwidget['whitelist'] = '".stripcslashes($row['widget_whitelist'])."';\n";

            $allwidget .= "?>";
                
            JAK_base::jakWriteinCache($cachewidgetdel, $allwidget, '');
           
        }

    }
}

// Group Chat caching
$cachegroupchat = APP_PATH.JAK_CACHE_DIRECTORY.'/groupchat1.php';

if (!file_exists($cachegroupchat)) {

    // Get the general settings out the database
    $resgc = $jakdb->select("groupchat", "*", ["active" => 1]);
    if (isset($resgc) && !empty($resgc)) {

        foreach ($resgc as $row) {

            // Now let us delete the widget cache file
            $cachegroupchat = APP_PATH.JAK_CACHE_DIRECTORY.'/groupchat'.$row['id'].'.php';
            if (file_exists($cachegroupchat)) {
                unlink($cachegroupchat);
            }

            $groupchat = "<?php\n\$groupchat = array();\n";

            $groupchat .= "\$groupchat['id'] = '".$row['id']."';\n\$groupchat['password'] = '".stripcslashes($row['password'])."';\n\$groupchat['title'] = '".stripcslashes($row['title'])."';\n\$groupchat['description'] = '".stripcslashes($row['description'])."';\n\$groupchat['opids'] = ".$row['opids'].";\n\$groupchat['maxclients'] = ".$row['maxclients'].";\n\$groupchat['lang'] = '".stripcslashes($row['lang'])."';\n\$groupchat['buttonimg'] = '".stripcslashes($row['buttonimg'])."';\n\$groupchat['floatpopup'] = ".$row['floatpopup'].";\n\$groupchat['floatcss'] = '".stripcslashes($row['floatcss'])."';\n\$groupchat['active'] = ".$row['active'].";\n";

            $groupchat .= "?>";
                
            JAK_base::jakWriteinCache($cachegroupchat, $groupchat, '');
           
        }

    }
}

// timezone from server
date_default_timezone_set(JAK_TIMEZONESERVER);
$jakdb->query('SET time_zone = "'.date("P").'"');

// Check if https is activated
if (JAK_SITEHTTPS) {
    define('BASE_URL', 'https://' . FULL_SITE_DOMAIN . _APP_MAIN_DIR . '/');
} else {
    define('BASE_URL', 'http://' . FULL_SITE_DOMAIN . _APP_MAIN_DIR . '/');
}

// Get the users ip address
$ipa = get_ip_address();

// Set all users to not logged in
$userislogged = $getuid = $getcid = 0;
// Get the language file if different from settings
$BT_LANGUAGE = JAK_LANG;
// Check if operator is logged in
$jakuserlogin = new JAK_userlogin();
$jakuserrow = $jakuserlogin->jakChecklogged();
$jakuser = new JAK_user($jakuserrow);
if (is_numeric($jakuser->getVar("id"))) {
    $getuid = $jakuser->getVar("id");
    $jakuserlogin->jakUpdatelastactivity($getuid);
    $userislogged = true;
    // Get the operator language
    if ($jakuser->getVar("language")) $BT_LANGUAGE = $jakuser->getVar("language");
}
define('JAK_USERID', $getuid);

// Only the SuperAdmin in the config file see everything
if (JAK_USERID && $jakuser->jakSuperadminaccess(JAK_USERID)) {
    define('JAK_SUPERADMINACCESS', true);
} else {
    define('JAK_SUPERADMINACCESS', false);
}

// Check if client is logged in when no operator is logged
if (!$userislogged) {
    $jakclientlogin = new JAK_clientlogin();
    $jakclientrow = $jakclientlogin->jakChecklogged();
    $jakclient = new JAK_client($jakclientrow);
    if (is_numeric($jakclient->getVar("id"))) {
        $getcid = $jakclient->getVar("id");
        $jakclientlogin->jakUpdatelastactivity($getcid);
        $userislogged = true;
        // Get the client language
        if ($jakclient->getVar("language")) $BT_LANGUAGE = $jakuser->getVar("language");
    }
}
define('JAK_CLIENTID', $getcid);

// Get the copyright Link
define('JAK_COPYRIGHT_LINK', $jakhs['copyright']);

// At last set define to true for user is logged in
define('JAK_USERISLOGGED', $userislogged);
?>